@@ -38,7 +38,7 @@ class OEmbedPresenter
   end
 
   def post_author_url
-   Rails.application.routes.url_helpers.person_url(@post.author, :host => AppConfig.pod_uri.host)
+    AppConfig.url_to(Rails.application.routes.url_helpers.person_path(@post.author))
   end
 
   def iframe_html
