@@ -40,7 +40,7 @@ module Federated
     end
 
     def fetch_parent guid
-      Diaspora::Fetcher::Single.find_or_fetch_from_remote guid, diaspora_handle
+      raise Diaspora::PostNotFetchable
     end
   end
 end
